@@ -520,6 +520,14 @@ class OpenStackConfig(object):
                 nat_destination=get_boolean(net.get('nat_destination')),
                 default_interface=get_boolean(net.get('default_interface')),
             )
+            # routes_ipv4_externally defaults to the value of routes_externally
+            network['routes_ipv4_externally'] = get_boolean(
+                net.get(
+                    'routes_ipv4_externally', network['routes_externally']))
+            # routes_ipv6_externally defaults to the value of routes_externally
+            network['routes_ipv6_externally'] = get_boolean(
+                net.get(
+                    'routes_ipv6_externally', network['routes_externally']))
             networks.append(network)
 
         for key in ('external_network', 'internal_network'):
@@ -562,6 +570,7 @@ class OpenStackConfig(object):
             for key in possible_values:
                 if target_key in cloud['auth'] and key not in cloud['auth']:
                     cloud['auth'][key] = cloud['auth'][target_key]
+            cloud.pop(target_key, None)
             cloud['auth'].pop(target_key, None)
         return cloud
 
